@@ -10,7 +10,6 @@ import os
 import sys
 
 from udiskie.compat import basestring
-from udiskie.common import setdefault
 
 
 __all__ = ['DeviceFilter',
@@ -177,20 +176,6 @@ class Config(object):
         return [os.path.join(config_home, 'udiskie', 'config.yml'),
                 os.path.join(config_home, 'udiskie', 'config.json')]
 
-    @classmethod
-    def default_program_options(cls):
-        """
-        Return the default program options.
-
-        :rtype: dict
-        """
-        return {'udisks_version': 0,
-                'password_prompt': 'zenity',
-                'tray': False,
-                'automount': True,
-                'notify': True,
-                'file_manager': 'xdg-open'}
-
     @classmethod
     def from_file(cls, path=None):
         """
@@ -201,6 +186,7 @@ class Config(object):
         :rtype: Config
         :raises IOError: if the path does not exist
         """
+        # None => use default
         if path is None:
             for path in cls.default_pathes():
                 try:
@@ -214,6 +200,9 @@ class Config(object):
                         "Failed to read {0!r}: {1}"
                         .format(path, sys.exc_info()[1]))
             return cls({})
+        # False/'' => no config
+        if not path:
+            return cls({})
         if os.path.splitext(path)[1].lower() == '.json':
             from json import load
         else:
@@ -237,7 +226,6 @@ class Config(object):
     def program_options(self):
         """Get the program options dictionary from the config file."""
         config_options = self._data.get('program_options', {}).copy()
-        setdefault(config_options, self.default_program_options())
         return config_options
 
     @property
